.epi2melabs-autorun-enabled .CodeMirror:after {
    height: 10px;
    width: 10px;
    display: block;
    content: '';
    position: absolute;
    right: 10px;
    top: 10px;
    border-radius: 50%;
    background-color: blueviolet;
}